@@ -1,17 +1,20 @@
 """AI-Trackdown adapter implementation."""
 
+import builtins
 import json
-from pathlib import Path
-from typing import List, Optional, Dict, Any, Union
 from datetime import datetime
+from pathlib import Path
+from typing import Any, Optional, Union
 
 from ..core.adapter import BaseAdapter
-from ..core.models import Epic, Task, Comment, SearchQuery, TicketState, Priority
+from ..core.models import Comment, Epic, Priority, SearchQuery, Task, TicketState
 from ..core.registry import AdapterRegistry
 
 # Import ai-trackdown-pytools when available
 try:
-    from ai_trackdown_pytools import AITrackdown, Ticket as AITicket
+    from ai_trackdown_pytools import AITrackdown
+    from ai_trackdown_pytools import Ticket as AITicket
+
     HAS_AITRACKDOWN = True
 except ImportError:
     HAS_AITRACKDOWN = False
@@ -22,11 +25,12 @@ except ImportError:
 class AITrackdownAdapter(BaseAdapter[Task]):
     """Adapter for AI-Trackdown ticket system."""
 
-    def __init__(self, config: Dict[str, Any]):
+    def __init__(self, config: dict[str, Any]):
         """Initialize AI-Trackdown adapter.
 
         Args:
             config: Configuration with 'base_path' for tickets directory
+
         """
         super().__init__(config)
         self.base_path = Path(config.get("base_path", ".aitrackdown"))
@@ -47,6 +51,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
 
         Returns:
             (is_valid, error_message) - Always returns (True, "") for AITrackdown
+
         """
         # AITrackdown is file-based and doesn't require API credentials
         # Just verify the base_path is accessible
@@ -54,7 +59,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             return False, "AITrackdown base_path is required in configuration"
         return True, ""
 
-    def _get_state_mapping(self) -> Dict[TicketState, str]:
+    def _get_state_mapping(self) -> dict[TicketState, str]:
         """Map universal states to AI-Trackdown states."""
         return {
             TicketState.OPEN: "open",
@@ -80,7 +85,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         except ValueError:
             return Priority.MEDIUM
 
-    def _task_from_ai_ticket(self, ai_ticket: Dict[str, Any]) -> Task:
+    def _task_from_ai_ticket(self, ai_ticket: dict[str, Any]) -> Task:
         """Convert AI-Trackdown ticket to universal Task."""
         return Task(
             id=ai_ticket.get("id"),
@@ -92,14 +97,20 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             parent_issue=ai_ticket.get("parent_issue"),
             parent_epic=ai_ticket.get("parent_epic"),
             assignee=ai_ticket.get("assignee"),
-            created_at=datetime.fromisoformat(ai_ticket["created_at"])
-            if "created_at" in ai_ticket else None,
-            updated_at=datetime.fromisoformat(ai_ticket["updated_at"])
-            if "updated_at" in ai_ticket else None,
+            created_at=(
+                datetime.fromisoformat(ai_ticket["created_at"])
+                if "created_at" in ai_ticket
+                else None
+            ),
+            updated_at=(
+                datetime.fromisoformat(ai_ticket["updated_at"])
+                if "updated_at" in ai_ticket
+                else None
+            ),
             metadata={"ai_trackdown": ai_ticket},
         )
 
-    def _epic_from_ai_ticket(self, ai_ticket: Dict[str, Any]) -> Epic:
+    def _epic_from_ai_ticket(self, ai_ticket: dict[str, Any]) -> Epic:
         """Convert AI-Trackdown ticket to universal Epic."""
         return Epic(
             id=ai_ticket.get("id"),
@@ -109,14 +120,20 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             priority=self._priority_from_ai(ai_ticket.get("priority", "medium")),
             tags=ai_ticket.get("tags", []),
             child_issues=ai_ticket.get("child_issues", []),
-            created_at=datetime.fromisoformat(ai_ticket["created_at"])
-            if "created_at" in ai_ticket and ai_ticket["created_at"] else None,
-            updated_at=datetime.fromisoformat(ai_ticket["updated_at"])
-            if "updated_at" in ai_ticket and ai_ticket["updated_at"] else None,
+            created_at=(
+                datetime.fromisoformat(ai_ticket["created_at"])
+                if "created_at" in ai_ticket and ai_ticket["created_at"]
+                else None
+            ),
+            updated_at=(
+                datetime.fromisoformat(ai_ticket["updated_at"])
+                if "updated_at" in ai_ticket and ai_ticket["updated_at"]
+                else None
+            ),
             metadata={"ai_trackdown": ai_ticket},
         )
 
-    def _task_to_ai_ticket(self, task: Task) -> Dict[str, Any]:
+    def _task_to_ai_ticket(self, task: Task) -> dict[str, Any]:
         """Convert universal Task to AI-Trackdown ticket."""
         # Handle enum values that may be stored as strings due to use_enum_values=True
         state_value = task.state
@@ -124,7 +141,9 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             state_value = self._get_state_mapping()[task.state]
         elif isinstance(task.state, str):
             # Already a string, map to AI-Trackdown format if needed
-            state_value = task.state.replace('_', '-')  # Convert snake_case to kebab-case
+            state_value = task.state.replace(
+                "_", "-"
+            )  # Convert snake_case to kebab-case
 
         return {
             "id": task.id,
@@ -141,7 +160,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             "type": "task",
         }
 
-    def _epic_to_ai_ticket(self, epic: Epic) -> Dict[str, Any]:
+    def _epic_to_ai_ticket(self, epic: Epic) -> dict[str, Any]:
         """Convert universal Epic to AI-Trackdown ticket."""
         # Handle enum values that may be stored as strings due to use_enum_values=True
         state_value = epic.state
@@ -149,7 +168,9 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             state_value = self._get_state_mapping()[epic.state]
         elif isinstance(epic.state, str):
             # Already a string, map to AI-Trackdown format if needed
-            state_value = epic.state.replace('_', '-')  # Convert snake_case to kebab-case
+            state_value = epic.state.replace(
+                "_", "-"
+            )  # Convert snake_case to kebab-case
 
         return {
             "id": epic.id,
@@ -164,15 +185,15 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             "type": "epic",
         }
 
-    def _read_ticket_file(self, ticket_id: str) -> Optional[Dict[str, Any]]:
+    def _read_ticket_file(self, ticket_id: str) -> Optional[dict[str, Any]]:
         """Read ticket from file system."""
         ticket_file = self.tickets_dir / f"{ticket_id}.json"
         if ticket_file.exists():
-            with open(ticket_file, "r") as f:
+            with open(ticket_file) as f:
                 return json.load(f)
         return None
 
-    def _write_ticket_file(self, ticket_id: str, data: Dict[str, Any]) -> None:
+    def _write_ticket_file(self, ticket_id: str, data: dict[str, Any]) -> None:
         """Write ticket to file system."""
         ticket_file = self.tickets_dir / f"{ticket_id}.json"
         with open(ticket_file, "w") as f:
@@ -214,6 +235,64 @@ class AITrackdownAdapter(BaseAdapter[Task]):
 
         return ticket
 
+    async def create_epic(self, title: str, description: str = None, **kwargs) -> Epic:
+        """Create a new epic.
+
+        Args:
+            title: Epic title
+            description: Epic description
+            **kwargs: Additional epic properties
+
+        Returns:
+            Created Epic instance
+        """
+        epic = Epic(
+            title=title,
+            description=description,
+            **kwargs
+        )
+        return await self.create(epic)
+
+    async def create_issue(self, title: str, parent_epic: str = None, description: str = None, **kwargs) -> Task:
+        """Create a new issue.
+
+        Args:
+            title: Issue title
+            parent_epic: Parent epic ID
+            description: Issue description
+            **kwargs: Additional issue properties
+
+        Returns:
+            Created Task instance (representing an issue)
+        """
+        task = Task(
+            title=title,
+            description=description,
+            parent_epic=parent_epic,
+            **kwargs
+        )
+        return await self.create(task)
+
+    async def create_task(self, title: str, parent_id: str, description: str = None, **kwargs) -> Task:
+        """Create a new task under an issue.
+
+        Args:
+            title: Task title
+            parent_id: Parent issue ID
+            description: Task description
+            **kwargs: Additional task properties
+
+        Returns:
+            Created Task instance
+        """
+        task = Task(
+            title=title,
+            description=description,
+            parent_issue=parent_id,
+            **kwargs
+        )
+        return await self.create(task)
+
     async def read(self, ticket_id: str) -> Optional[Union[Task, Epic]]:
         """Read a task by ID."""
         if self.tracker:
@@ -230,9 +309,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         return None
 
     async def update(
-        self,
-        ticket_id: str,
-        updates: Union[Dict[str, Any], Task]
+        self, ticket_id: str, updates: Union[dict[str, Any], Task]
     ) -> Optional[Task]:
         """Update a task."""
         # Read existing ticket
@@ -244,7 +321,11 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         if isinstance(updates, Task):
             # If updates is a Task object, copy all fields except frozen ones
             for field in updates.__fields__:
-                if field not in ['ticket_type'] and hasattr(updates, field) and getattr(updates, field) is not None:
+                if (
+                    field not in ["ticket_type"]
+                    and hasattr(updates, field)
+                    and getattr(updates, field) is not None
+                ):
                     setattr(existing, field, getattr(updates, field))
         else:
             # If updates is a dictionary
@@ -275,11 +356,8 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         return False
 
     async def list(
-        self,
-        limit: int = 10,
-        offset: int = 0,
-        filters: Optional[Dict[str, Any]] = None
-    ) -> List[Task]:
+        self, limit: int = 10, offset: int = 0, filters: Optional[dict[str, Any]] = None
+    ) -> list[Task]:
         """List tasks with pagination."""
         tasks = []
 
@@ -295,7 +373,7 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             # Direct file operation - read all files, filter, then paginate
             ticket_files = sorted(self.tickets_dir.glob("*.json"))
             for ticket_file in ticket_files:
-                with open(ticket_file, "r") as f:
+                with open(ticket_file) as f:
                     ai_ticket = json.load(f)
                     task = self._task_from_ai_ticket(ai_ticket)
 
@@ -319,11 +397,11 @@ class AITrackdownAdapter(BaseAdapter[Task]):
                     tasks.append(task)
 
             # Apply pagination after filtering
-            tasks = tasks[offset:offset + limit]
+            tasks = tasks[offset : offset + limit]
 
         return tasks
 
-    async def search(self, query: SearchQuery) -> List[Task]:
+    async def search(self, query: SearchQuery) -> builtins.list[Task]:
         """Search tasks using query parameters."""
         filters = {}
         if query.state:
@@ -340,8 +418,10 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             # Text search in title and description
             if query.query:
                 search_text = query.query.lower()
-                if (search_text not in (task.title or "").lower() and
-                    search_text not in (task.description or "").lower()):
+                if (
+                    search_text not in (task.title or "").lower()
+                    and search_text not in (task.description or "").lower()
+                ):
                     continue
 
             # Tag filtering
@@ -356,12 +436,10 @@ class AITrackdownAdapter(BaseAdapter[Task]):
             results.append(task)
 
         # Apply pagination
-        return results[query.offset:query.offset + query.limit]
+        return results[query.offset : query.offset + query.limit]
 
     async def transition_state(
-        self,
-        ticket_id: str,
-        target_state: TicketState
+        self, ticket_id: str, target_state: TicketState
     ) -> Optional[Task]:
         """Transition task to new state."""
         # Validate transition
@@ -390,19 +468,16 @@ class AITrackdownAdapter(BaseAdapter[Task]):
         return comment
 
     async def get_comments(
-        self,
-        ticket_id: str,
-        limit: int = 10,
-        offset: int = 0
-    ) -> List[Comment]:
+        self, ticket_id: str, limit: int = 10, offset: int = 0
+    ) -> builtins.list[Comment]:
         """Get comments for a task."""
         comments = []
         comments_dir = self.base_path / "comments"
 
         if comments_dir.exists():
             comment_files = sorted(comments_dir.glob("*.json"))
-            for comment_file in comment_files[offset:offset + limit]:
-                with open(comment_file, "r") as f:
+            for comment_file in comment_files[offset : offset + limit]:
+                with open(comment_file) as f:
                     data = json.load(f)
                     if data.get("ticket_id") == ticket_id:
                         comments.append(Comment(**data))
@@ -411,4 +486,4 @@ class AITrackdownAdapter(BaseAdapter[Task]):
 
 
 # Register the adapter
-AdapterRegistry.register("aitrackdown", AITrackdownAdapter)
\ No newline at end of file
+AdapterRegistry.register("aitrackdown", AITrackdownAdapter)
