@@ -2,71 +2,131 @@
 
 import asyncio
 import json
+import logging
 import os
-from typing import Optional, Dict, Any, Callable, TypeVar, List
-from pathlib import Path
 from functools import wraps
+from pathlib import Path
+from typing import Any, Callable, Optional, TypeVar
 
 import typer
 from rich.console import Console
-from rich.table import Table
-from rich.panel import Panel
 from rich.progress import Progress, SpinnerColumn, TextColumn
+from rich.table import Table
 
-from ..core import Task, TicketState, Priority, AdapterRegistry
-from ..core.config import get_config, get_adapter_config
-from ..queue import Queue, WorkerManager, QueueStatus
+from ..core import AdapterRegistry, Priority, Task, TicketState
+from ..queue import Queue, QueueStatus, WorkerManager
 
 # Type variable for async functions
-T = TypeVar('T')
+T = TypeVar("T")
 
 console = Console()
+logger = logging.getLogger(__name__)
 
 
 class CommonPatterns:
     """Common CLI patterns and utilities."""
 
-    # Configuration file management
-    CONFIG_FILE = Path.home() / ".mcp-ticketer" / "config.json"
+    # Configuration file management - PROJECT-LOCAL ONLY
+    CONFIG_FILE = Path.cwd() / ".mcp-ticketer" / "config.json"
 
     @staticmethod
     def load_config() -> dict:
-        """Load configuration from file.
+        """Load configuration from project-local config file with environment discovery fallback.
+
+        SECURITY: This method ONLY reads from the current project directory
+        to prevent configuration leakage across projects. It will NEVER read
+        from user home directory or system-wide locations.
 
         Resolution order:
         1. Project-specific config (.mcp-ticketer/config.json in cwd)
-        2. Global config (~/.mcp-ticketer/config.json)
+        2. Environment discovery (environment variables and .env files in cwd)
+        3. Default to aitrackdown adapter
 
         Returns:
-            Configuration dictionary
+            Configuration dictionary with adapter and config keys.
+            Defaults to aitrackdown if no local config exists.
+
         """
-        # Check project-specific config first
+        # ONLY check project-specific config in current working directory
         project_config = Path.cwd() / ".mcp-ticketer" / "config.json"
         if project_config.exists():
+            # Validate that config file is actually in project directory
             try:
-                with open(project_config, "r") as f:
-                    return json.load(f)
-            except (json.JSONDecodeError, IOError) as e:
-                console.print(f"[yellow]Warning: Could not load project config: {e}[/yellow]")
-                # Fall through to global config
+                if not project_config.resolve().is_relative_to(Path.cwd().resolve()):
+                    logger.error(
+                        f"Security violation: Config file {project_config} "
+                        "is not within project directory"
+                    )
+                    raise ValueError(
+                        f"Security violation: Config file {project_config} "
+                        "is not within project directory"
+                    )
+            except (ValueError, RuntimeError):
+                # is_relative_to may raise ValueError in some cases
+                pass
 
-        # Fall back to global config
-        if CommonPatterns.CONFIG_FILE.exists():
             try:
-                with open(CommonPatterns.CONFIG_FILE, "r") as f:
-                    return json.load(f)
-            except (json.JSONDecodeError, IOError) as e:
-                console.print(f"[yellow]Warning: Could not load global config: {e}[/yellow]")
+                with open(project_config) as f:
+                    config = json.load(f)
+                    logger.info(
+                        f"Loaded configuration from project-local: {project_config}"
+                    )
+                    return config
+            except (OSError, json.JSONDecodeError) as e:
+                logger.warning(f"Could not load project config: {e}, using defaults")
+                console.print(
+                    f"[yellow]Warning: Could not load project config: {e}[/yellow]"
+                )
 
-        # Default fallback
+        # Try environment discovery as fallback
+        try:
+            from ..core.config import ConfigurationManager
+            config_manager = ConfigurationManager()
+            app_config = config_manager.load_config()
+
+            # Convert AppConfig to legacy dict format for CLI compatibility
+            enabled_adapters = app_config.get_enabled_adapters()
+            if enabled_adapters:
+                # Use the first enabled adapter as default
+                default_adapter = app_config.default_adapter or list(enabled_adapters.keys())[0]
+
+                # Convert to legacy format
+                legacy_config = {
+                    "default_adapter": default_adapter,
+                    "adapters": {}
+                }
+
+                # Convert adapter configs to dict format
+                for name, adapter_config in enabled_adapters.items():
+                    if hasattr(adapter_config, 'model_dump'):
+                        legacy_config["adapters"][name] = adapter_config.model_dump(exclude_none=False)
+                    elif hasattr(adapter_config, 'dict'):
+                        legacy_config["adapters"][name] = adapter_config.dict()
+                    else:
+                        legacy_config["adapters"][name] = adapter_config
+
+                logger.info(f"Loaded configuration from environment discovery: {list(enabled_adapters.keys())}")
+                return legacy_config
+
+        except Exception as e:
+            logger.warning(f"Environment discovery failed: {e}")
+
+        # Default to aitrackdown with local base path
+        logger.info("No project-local config found, defaulting to aitrackdown adapter")
         return {"adapter": "aitrackdown", "config": {"base_path": ".aitrackdown"}}
 
     @staticmethod
     def save_config(config: dict) -> None:
-        """Save configuration to file."""
-        CommonPatterns.CONFIG_FILE.parent.mkdir(parents=True, exist_ok=True)
-        with open(CommonPatterns.CONFIG_FILE, "w") as f:
+        """Save configuration to project-local config file ONLY.
+
+        SECURITY: This method ONLY saves to the current project directory
+        to prevent configuration leakage across projects.
+        """
+        project_config = Path.cwd() / ".mcp-ticketer" / "config.json"
+        project_config.parent.mkdir(parents=True, exist_ok=True)
+        with open(project_config, "w") as f:
             json.dump(config, f, indent=2)
+        logger.info(f"Saved configuration to project-local: {project_config}")
 
     @staticmethod
     def merge_config(updates: dict) -> dict:
@@ -89,7 +149,9 @@ class CommonPatterns:
         return config
 
     @staticmethod
-    def get_adapter(override_adapter: Optional[str] = None, override_config: Optional[dict] = None):
+    def get_adapter(
+        override_adapter: Optional[str] = None, override_config: Optional[dict] = None
+    ):
         """Get configured adapter instance with environment variable support."""
         config = CommonPatterns.load_config()
 
@@ -138,10 +200,10 @@ class CommonPatterns:
 
     @staticmethod
     def queue_operation(
-        ticket_data: Dict[str, Any],
+        ticket_data: dict[str, Any],
         operation: str,
         adapter_name: Optional[str] = None,
-        show_progress: bool = True
+        show_progress: bool = True,
     ) -> str:
         """Queue an operation and optionally start the worker."""
         if not adapter_name:
@@ -151,14 +213,14 @@ class CommonPatterns:
         # Add to queue
         queue = Queue()
         queue_id = queue.add(
-            ticket_data=ticket_data,
-            adapter=adapter_name,
-            operation=operation
+            ticket_data=ticket_data, adapter=adapter_name, operation=operation
         )
 
         if show_progress:
             console.print(f"[green]✓[/green] Queued {operation}: {queue_id}")
-            console.print("[dim]Use 'mcp-ticketer check {queue_id}' to check progress[/dim]")
+            console.print(
+                "[dim]Use 'mcp-ticketer check {queue_id}' to check progress[/dim]"
+            )
 
         # Start worker if needed
         manager = WorkerManager()
@@ -169,7 +231,7 @@ class CommonPatterns:
         return queue_id
 
     @staticmethod
-    def display_ticket_table(tickets: List[Task], title: str = "Tickets") -> None:
+    def display_ticket_table(tickets: list[Task], title: str = "Tickets") -> None:
         """Display tickets in a formatted table."""
         if not tickets:
             console.print("[yellow]No tickets found[/yellow]")
@@ -194,7 +256,7 @@ class CommonPatterns:
         console.print(table)
 
     @staticmethod
-    def display_ticket_details(ticket: Task, comments: Optional[List] = None) -> None:
+    def display_ticket_details(ticket: Task, comments: Optional[list] = None) -> None:
         """Display detailed ticket information."""
         console.print(f"\n[bold]Ticket: {ticket.id}[/bold]")
         console.print(f"Title: {ticket.title}")
@@ -202,7 +264,7 @@ class CommonPatterns:
         console.print(f"Priority: [yellow]{ticket.priority}[/yellow]")
 
         if ticket.description:
-            console.print(f"\n[dim]Description:[/dim]")
+            console.print("\n[dim]Description:[/dim]")
             console.print(ticket.description)
 
         if ticket.tags:
@@ -238,32 +300,41 @@ class CommonPatterns:
         # Show worker status
         worker_status = manager.get_status()
         if worker_status["running"]:
-            console.print(f"\n[green]● Worker is running[/green] (PID: {worker_status.get('pid')})")
+            console.print(
+                f"\n[green]● Worker is running[/green] (PID: {worker_status.get('pid')})"
+            )
         else:
             console.print("\n[red]○ Worker is not running[/red]")
             if pending > 0:
-                console.print("[yellow]Note: There are pending items. Start worker with 'mcp-ticketer queue start'[/yellow]")
+                console.print(
+                    "[yellow]Note: There are pending items. Start worker with 'mcp-ticketer queue start'[/yellow]"
+                )
 
 
 def async_command(f: Callable[..., T]) -> Callable[..., T]:
     """Decorator to handle async CLI commands."""
+
     @wraps(f)
     def wrapper(*args, **kwargs):
         return asyncio.run(f(*args, **kwargs))
+
     return wrapper
 
 
 def with_adapter(f: Callable) -> Callable:
     """Decorator to inject adapter instance into CLI commands."""
+
     @wraps(f)
     def wrapper(adapter: Optional[str] = None, *args, **kwargs):
         adapter_instance = CommonPatterns.get_adapter(override_adapter=adapter)
         return f(adapter_instance, *args, **kwargs)
+
     return wrapper
 
 
 def with_progress(message: str = "Processing..."):
     """Decorator to show progress spinner for long-running operations."""
+
     def decorator(f: Callable) -> Callable:
         @wraps(f)
         def wrapper(*args, **kwargs):
@@ -274,12 +345,15 @@ def with_progress(message: str = "Processing..."):
             ) as progress:
                 progress.add_task(description=message, total=None)
                 return f(*args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
 def validate_required_fields(**field_map):
     """Decorator to validate required fields are provided."""
+
     def decorator(f: Callable) -> Callable:
         @wraps(f)
         def wrapper(*args, **kwargs):
@@ -289,16 +363,21 @@ def validate_required_fields(**field_map):
                     missing_fields.append(display_name)
 
             if missing_fields:
-                console.print(f"[red]Error:[/red] Missing required fields: {', '.join(missing_fields)}")
+                console.print(
+                    f"[red]Error:[/red] Missing required fields: {', '.join(missing_fields)}"
+                )
                 raise typer.Exit(1)
 
             return f(*args, **kwargs)
+
         return wrapper
+
     return decorator
 
 
 def handle_adapter_errors(f: Callable) -> Callable:
     """Decorator to handle common adapter errors gracefully."""
+
     @wraps(f)
     def wrapper(*args, **kwargs):
         try:
@@ -314,6 +393,7 @@ def handle_adapter_errors(f: Callable) -> Callable:
         except Exception as e:
             console.print(f"[red]Unexpected Error:[/red] {e}")
             raise typer.Exit(1)
+
     return wrapper
 
 
@@ -321,7 +401,7 @@ class ConfigValidator:
     """Configuration validation utilities."""
 
     @staticmethod
-    def validate_adapter_config(adapter_type: str, config: dict) -> List[str]:
+    def validate_adapter_config(adapter_type: str, config: dict) -> list[str]:
         """Validate adapter configuration and return list of issues."""
         issues = []
 
@@ -350,7 +430,9 @@ class ConfigValidator:
                 if not config.get(field):
                     env_var = ConfigValidator._get_env_var(adapter_type, field)
                     if env_var and not os.getenv(env_var):
-                        issues.append(f"Missing {display_name} (config.{field} or {env_var})")
+                        issues.append(
+                            f"Missing {display_name} (config.{field} or {env_var})"
+                        )
 
         return issues
 
@@ -358,8 +440,16 @@ class ConfigValidator:
     def _get_env_var(adapter_type: str, field: str) -> Optional[str]:
         """Get corresponding environment variable name for a config field."""
         env_mapping = {
-            "github": {"token": "GITHUB_TOKEN", "owner": "GITHUB_OWNER", "repo": "GITHUB_REPO"},
-            "jira": {"api_token": "JIRA_API_TOKEN", "email": "JIRA_EMAIL", "server": "JIRA_SERVER"},
+            "github": {
+                "token": "GITHUB_TOKEN",
+                "owner": "GITHUB_OWNER",
+                "repo": "GITHUB_REPO",
+            },
+            "jira": {
+                "api_token": "JIRA_API_TOKEN",
+                "email": "JIRA_EMAIL",
+                "server": "JIRA_SERVER",
+            },
             "linear": {"api_key": "LINEAR_API_KEY"},
         }
         return env_mapping.get(adapter_type, {}).get(field)
@@ -406,7 +496,9 @@ class CommandBuilder:
         default_adapter = config.get("default_adapter", "aitrackdown")
         adapter_config = config.get("adapters", {}).get(default_adapter, {})
 
-        issues = ConfigValidator.validate_adapter_config(default_adapter, adapter_config)
+        issues = ConfigValidator.validate_adapter_config(
+            default_adapter, adapter_config
+        )
         if issues:
             console.print("[red]Configuration Issues:[/red]")
             for issue in issues:
@@ -417,6 +509,7 @@ class CommandBuilder:
 
 def create_standard_ticket_command(operation: str):
     """Create a standard ticket operation command."""
+
     def command_template(
         ticket_id: Optional[str] = None,
         title: Optional[str] = None,
@@ -424,7 +517,7 @@ def create_standard_ticket_command(operation: str):
         priority: Optional[Priority] = None,
         state: Optional[TicketState] = None,
         assignee: Optional[str] = None,
-        tags: Optional[List[str]] = None,
+        tags: Optional[list[str]] = None,
         adapter: Optional[str] = None,
     ):
         """Template for ticket commands."""
@@ -437,9 +530,11 @@ def create_standard_ticket_command(operation: str):
         if description:
             ticket_data["description"] = description
         if priority:
-            ticket_data["priority"] = priority.value if hasattr(priority, 'value') else priority
+            ticket_data["priority"] = (
+                priority.value if hasattr(priority, "value") else priority
+            )
         if state:
-            ticket_data["state"] = state.value if hasattr(state, 'value') else state
+            ticket_data["state"] = state.value if hasattr(state, "value") else state
         if assignee:
             ticket_data["assignee"] = assignee
         if tags:
@@ -466,7 +561,7 @@ class TicketCommands:
         adapter_instance,
         state: Optional[TicketState] = None,
         priority: Optional[Priority] = None,
-        limit: int = 10
+        limit: int = 10,
     ):
         """List tickets with filters."""
         filters = {}
@@ -482,9 +577,7 @@ class TicketCommands:
     @async_command
     @handle_adapter_errors
     async def show_ticket(
-        adapter_instance,
-        ticket_id: str,
-        show_comments: bool = False
+        adapter_instance, ticket_id: str, show_comments: bool = False
     ):
         """Show ticket details."""
         ticket = await adapter_instance.read(ticket_id)
@@ -503,9 +596,9 @@ class TicketCommands:
         title: str,
         description: Optional[str] = None,
         priority: Priority = Priority.MEDIUM,
-        tags: Optional[List[str]] = None,
+        tags: Optional[list[str]] = None,
         assignee: Optional[str] = None,
-        adapter: Optional[str] = None
+        adapter: Optional[str] = None,
     ) -> str:
         """Create a new ticket."""
         ticket_data = {
@@ -520,9 +613,7 @@ class TicketCommands:
 
     @staticmethod
     def update_ticket(
-        ticket_id: str,
-        updates: Dict[str, Any],
-        adapter: Optional[str] = None
+        ticket_id: str, updates: dict[str, Any], adapter: Optional[str] = None
     ) -> str:
         """Update a ticket."""
         if not updates:
@@ -534,14 +625,12 @@ class TicketCommands:
 
     @staticmethod
     def transition_ticket(
-        ticket_id: str,
-        state: TicketState,
-        adapter: Optional[str] = None
+        ticket_id: str, state: TicketState, adapter: Optional[str] = None
     ) -> str:
         """Transition ticket state."""
         ticket_data = {
             "ticket_id": ticket_id,
-            "state": state.value if hasattr(state, 'value') else state
+            "state": state.value if hasattr(state, "value") else state,
         }
 
-        return CommonPatterns.queue_operation(ticket_data, "transition", adapter)
\ No newline at end of file
+        return CommonPatterns.queue_operation(ticket_data, "transition", adapter)
