@@ -8,14 +8,14 @@ environment files, including:
 - Security validation
 """
 
-import os
 import logging
-from pathlib import Path
-from typing import Dict, Any, Optional, List, Tuple
 from dataclasses import dataclass, field
+from pathlib import Path
+from typing import Any, Optional
+
 from dotenv import dotenv_values
 
-from .project_config import AdapterType, AdapterConfig
+from .project_config import AdapterType
 
 logger = logging.getLogger(__name__)
 
@@ -30,8 +30,10 @@ LINEAR_KEY_PATTERNS = [
 
 LINEAR_TEAM_PATTERNS = [
     "LINEAR_TEAM_ID",
+    "LINEAR_TEAM_KEY",  # Added support for team key (e.g., "BTA")
     "LINEAR_TEAM",
     "MCP_TICKETER_LINEAR_TEAM_ID",
+    "MCP_TICKETER_LINEAR_TEAM_KEY",
 ]
 
 LINEAR_PROJECT_PATTERNS = [
@@ -105,9 +107,9 @@ class DiscoveredAdapter:
     """Information about a discovered adapter configuration."""
 
     adapter_type: str
-    config: Dict[str, Any]
+    config: dict[str, Any]
     confidence: float  # 0.0-1.0 how complete the configuration is
-    missing_fields: List[str] = field(default_factory=list)
+    missing_fields: list[str] = field(default_factory=list)
     found_in: str = ".env"  # Which file it was found in
 
     def is_complete(self) -> bool:
@@ -119,9 +121,9 @@ class DiscoveredAdapter:
 class DiscoveryResult:
     """Result of environment file discovery."""
 
-    adapters: List[DiscoveredAdapter] = field(default_factory=list)
-    warnings: List[str] = field(default_factory=list)
-    env_files_found: List[str] = field(default_factory=list)
+    adapters: list[DiscoveredAdapter] = field(default_factory=list)
+    warnings: list[str] = field(default_factory=list)
+    env_files_found: list[str] = field(default_factory=list)
 
     def get_primary_adapter(self) -> Optional[DiscoveredAdapter]:
         """Get the adapter with highest confidence and completeness."""
@@ -130,9 +132,7 @@ class DiscoveryResult:
 
         # Sort by: complete configs first, then by confidence
         sorted_adapters = sorted(
-            self.adapters,
-            key=lambda a: (a.is_complete(), a.confidence),
-            reverse=True
+            self.adapters, key=lambda a: (a.is_complete(), a.confidence), reverse=True
         )
         return sorted_adapters[0]
 
@@ -160,6 +160,7 @@ class EnvDiscovery:
 
         Args:
             project_path: Path to project root (defaults to cwd)
+
         """
         self.project_path = project_path or Path.cwd()
 
@@ -168,6 +169,7 @@ class EnvDiscovery:
 
         Returns:
             DiscoveryResult with found adapters and warnings
+
         """
         result = DiscoveryResult()
 
@@ -179,19 +181,27 @@ class EnvDiscovery:
             return result
 
         # Detect adapters
-        linear_adapter = self._detect_linear(env_vars, result.env_files_found[0] if result.env_files_found else ".env")
+        linear_adapter = self._detect_linear(
+            env_vars, result.env_files_found[0] if result.env_files_found else ".env"
+        )
         if linear_adapter:
             result.adapters.append(linear_adapter)
 
-        github_adapter = self._detect_github(env_vars, result.env_files_found[0] if result.env_files_found else ".env")
+        github_adapter = self._detect_github(
+            env_vars, result.env_files_found[0] if result.env_files_found else ".env"
+        )
         if github_adapter:
             result.adapters.append(github_adapter)
 
-        jira_adapter = self._detect_jira(env_vars, result.env_files_found[0] if result.env_files_found else ".env")
+        jira_adapter = self._detect_jira(
+            env_vars, result.env_files_found[0] if result.env_files_found else ".env"
+        )
         if jira_adapter:
             result.adapters.append(jira_adapter)
 
-        aitrackdown_adapter = self._detect_aitrackdown(env_vars, result.env_files_found[0] if result.env_files_found else ".env")
+        aitrackdown_adapter = self._detect_aitrackdown(
+            env_vars, result.env_files_found[0] if result.env_files_found else ".env"
+        )
         if aitrackdown_adapter:
             result.adapters.append(aitrackdown_adapter)
 
@@ -201,18 +211,31 @@ class EnvDiscovery:
 
         return result
 
-    def _load_env_files(self, result: DiscoveryResult) -> Dict[str, str]:
-        """Load environment variables from files.
+    def _load_env_files(self, result: DiscoveryResult) -> dict[str, str]:
+        """Load environment variables from files and actual environment.
+
+        Priority order (highest to lowest):
+        1. .env files (highest priority)
+        2. Environment variables (lowest priority)
 
         Args:
             result: DiscoveryResult to update with found files
 
         Returns:
             Merged dictionary of environment variables
-        """
-        merged_env: Dict[str, str] = {}
 
-        # Load files in reverse order (lowest priority first)
+        """
+        merged_env: dict[str, str] = {}
+
+        # First, load from actual environment variables (lowest priority)
+        import os
+        actual_env = {k: v for k, v in os.environ.items() if v}
+        merged_env.update(actual_env)
+        if actual_env:
+            result.env_files_found.append("environment")
+            logger.debug(f"Loaded {len(actual_env)} variables from environment")
+
+        # Load files in reverse order (higher priority than environment)
         for env_file in reversed(self.ENV_FILE_ORDER):
             file_path = self.project_path / env_file
             if file_path.exists():
@@ -229,7 +252,9 @@ class EnvDiscovery:
 
         return merged_env
 
-    def _find_key_value(self, env_vars: Dict[str, str], patterns: List[str]) -> Optional[str]:
+    def _find_key_value(
+        self, env_vars: dict[str, str], patterns: list[str]
+    ) -> Optional[str]:
         """Find first matching key value from patterns.
 
         Args:
@@ -238,13 +263,16 @@ class EnvDiscovery:
 
         Returns:
             Value if found, None otherwise
+
         """
         for pattern in patterns:
             if pattern in env_vars and env_vars[pattern]:
                 return env_vars[pattern]
         return None
 
-    def _detect_linear(self, env_vars: Dict[str, str], found_in: str) -> Optional[DiscoveredAdapter]:
+    def _detect_linear(
+        self, env_vars: dict[str, str], found_in: str
+    ) -> Optional[DiscoveredAdapter]:
         """Detect Linear adapter configuration.
 
         Args:
@@ -253,27 +281,34 @@ class EnvDiscovery:
 
         Returns:
             DiscoveredAdapter if Linear config detected, None otherwise
+
         """
         api_key = self._find_key_value(env_vars, LINEAR_KEY_PATTERNS)
 
         if not api_key:
             return None
 
-        config: Dict[str, Any] = {
+        config: dict[str, Any] = {
             "api_key": api_key,
             "adapter": AdapterType.LINEAR.value,
         }
 
-        missing_fields: List[str] = []
+        missing_fields: list[str] = []
         confidence = 0.6  # Has API key
 
-        # Extract team ID (recommended but not required)
-        team_id = self._find_key_value(env_vars, LINEAR_TEAM_PATTERNS)
-        if team_id:
-            config["team_id"] = team_id
+        # Extract team identifier (either team_id or team_key is required)
+        team_identifier = self._find_key_value(env_vars, LINEAR_TEAM_PATTERNS)
+        if team_identifier:
+            # Determine if it's a team_id (UUID format) or team_key (short string)
+            if len(team_identifier) > 20 and '-' in team_identifier:
+                # Looks like a UUID (team_id)
+                config["team_id"] = team_identifier
+            else:
+                # Looks like a short key (team_key)
+                config["team_key"] = team_identifier
             confidence += 0.3
         else:
-            missing_fields.append("team_id (recommended)")
+            missing_fields.append("team_id or team_key (required)")
 
         # Extract project ID (optional)
         project_id = self._find_key_value(env_vars, LINEAR_PROJECT_PATTERNS)
@@ -289,7 +324,9 @@ class EnvDiscovery:
             found_in=found_in,
         )
 
-    def _detect_github(self, env_vars: Dict[str, str], found_in: str) -> Optional[DiscoveredAdapter]:
+    def _detect_github(
+        self, env_vars: dict[str, str], found_in: str
+    ) -> Optional[DiscoveredAdapter]:
         """Detect GitHub adapter configuration.
 
         Args:
@@ -298,18 +335,19 @@ class EnvDiscovery:
 
         Returns:
             DiscoveredAdapter if GitHub config detected, None otherwise
+
         """
         token = self._find_key_value(env_vars, GITHUB_TOKEN_PATTERNS)
 
         if not token:
             return None
 
-        config: Dict[str, Any] = {
+        config: dict[str, Any] = {
             "token": token,
             "adapter": AdapterType.GITHUB.value,
         }
 
-        missing_fields: List[str] = []
+        missing_fields: list[str] = []
         confidence = 0.4  # Has token
 
         # Try to extract owner/repo from combined field
@@ -345,7 +383,9 @@ class EnvDiscovery:
             found_in=found_in,
         )
 
-    def _detect_jira(self, env_vars: Dict[str, str], found_in: str) -> Optional[DiscoveredAdapter]:
+    def _detect_jira(
+        self, env_vars: dict[str, str], found_in: str
+    ) -> Optional[DiscoveredAdapter]:
         """Detect JIRA adapter configuration.
 
         Args:
@@ -354,18 +394,19 @@ class EnvDiscovery:
 
         Returns:
             DiscoveredAdapter if JIRA config detected, None otherwise
+
         """
         api_token = self._find_key_value(env_vars, JIRA_TOKEN_PATTERNS)
 
         if not api_token:
             return None
 
-        config: Dict[str, Any] = {
+        config: dict[str, Any] = {
             "api_token": api_token,
             "adapter": AdapterType.JIRA.value,
         }
 
-        missing_fields: List[str] = []
+        missing_fields: list[str] = []
         confidence = 0.3  # Has token
 
         # Extract server (required)
@@ -398,7 +439,9 @@ class EnvDiscovery:
             found_in=found_in,
         )
 
-    def _detect_aitrackdown(self, env_vars: Dict[str, str], found_in: str) -> Optional[DiscoveredAdapter]:
+    def _detect_aitrackdown(
+        self, env_vars: dict[str, str], found_in: str
+    ) -> Optional[DiscoveredAdapter]:
         """Detect AITrackdown adapter configuration.
 
         Args:
@@ -407,6 +450,7 @@ class EnvDiscovery:
 
         Returns:
             DiscoveredAdapter if AITrackdown config detected, None otherwise
+
         """
         base_path = self._find_key_value(env_vars, AITRACKDOWN_PATH_PATTERNS)
 
@@ -415,7 +459,7 @@ class EnvDiscovery:
         if not base_path and not aitrackdown_dir.exists():
             return None
 
-        config: Dict[str, Any] = {
+        config: dict[str, Any] = {
             "adapter": AdapterType.AITRACKDOWN.value,
         }
 
@@ -435,13 +479,14 @@ class EnvDiscovery:
             found_in=found_in,
         )
 
-    def _validate_security(self) -> List[str]:
+    def _validate_security(self) -> list[str]:
         """Validate security of environment files.
 
         Returns:
             List of security warnings
+
         """
-        warnings: List[str] = []
+        warnings: list[str] = []
 
         # Check if .env files are tracked in git
         gitignore_path = self.project_path / ".gitignore"
@@ -460,7 +505,7 @@ class EnvDiscovery:
         # Check if .gitignore exists and has .env patterns
         if gitignore_path.exists():
             try:
-                with open(gitignore_path, 'r') as f:
+                with open(gitignore_path) as f:
                     gitignore_content = f.read()
                     if ".env" not in gitignore_content:
                         warnings.append(
@@ -479,6 +524,7 @@ class EnvDiscovery:
 
         Returns:
             True if file is tracked in git, False otherwise
+
         """
         import subprocess
 
@@ -498,7 +544,7 @@ class EnvDiscovery:
             logger.debug(f"Git check failed: {e}")
             return False
 
-    def validate_discovered_config(self, adapter: DiscoveredAdapter) -> List[str]:
+    def validate_discovered_config(self, adapter: DiscoveredAdapter) -> list[str]:
         """Validate a discovered adapter configuration.
 
         Args:
@@ -506,8 +552,9 @@ class EnvDiscovery:
 
         Returns:
             List of validation warnings
+
         """
-        warnings: List[str] = []
+        warnings: list[str] = []
 
         # Check API key/token length (basic sanity check)
         if adapter.adapter_type == AdapterType.LINEAR.value:
@@ -522,12 +569,16 @@ class EnvDiscovery:
 
             # Validate token prefix
             if token and not token.startswith(("ghp_", "gho_", "ghu_", "ghs_", "ghr_")):
-                warnings.append("⚠️  GitHub token doesn't match expected format (should start with ghp_, gho_, etc.)")
+                warnings.append(
+                    "⚠️  GitHub token doesn't match expected format (should start with ghp_, gho_, etc.)"
+                )
 
         elif adapter.adapter_type == AdapterType.JIRA.value:
             server = adapter.config.get("server", "")
             if server and not server.startswith(("http://", "https://")):
-                warnings.append("⚠️  JIRA server URL should start with http:// or https://")
+                warnings.append(
+                    "⚠️  JIRA server URL should start with http:// or https://"
+                )
 
             email = adapter.config.get("email", "")
             if email and "@" not in email:
@@ -550,6 +601,7 @@ def discover_config(project_path: Optional[Path] = None) -> DiscoveryResult:
 
     Returns:
         DiscoveryResult with found adapters and warnings
+
     """
     discovery = EnvDiscovery(project_path)
     return discovery.discover()
