@@ -2,12 +2,14 @@
 
 from datetime import datetime
 from enum import Enum
-from typing import Optional, Dict, Any, List
-from pydantic import BaseModel, Field, ConfigDict
+from typing import Any, Optional
+
+from pydantic import BaseModel, ConfigDict, Field
 
 
 class Priority(str, Enum):
     """Universal priority levels."""
+
     LOW = "low"
     MEDIUM = "medium"
     HIGH = "high"
@@ -16,14 +18,16 @@ class Priority(str, Enum):
 
 class TicketType(str, Enum):
     """Ticket type hierarchy."""
-    EPIC = "epic"        # Strategic level (Projects in Linear, Milestones in GitHub)
-    ISSUE = "issue"      # Work item level (standard issues/tasks)
-    TASK = "task"        # Sub-task level (sub-issues, checkboxes)
+
+    EPIC = "epic"  # Strategic level (Projects in Linear, Milestones in GitHub)
+    ISSUE = "issue"  # Work item level (standard issues/tasks)
+    TASK = "task"  # Sub-task level (sub-issues, checkboxes)
     SUBTASK = "subtask"  # Alias for task (for clarity)
 
 
 class TicketState(str, Enum):
     """Universal ticket states with state machine abstraction."""
+
     OPEN = "open"
     IN_PROGRESS = "in_progress"
     READY = "ready"
@@ -34,7 +38,7 @@ class TicketState(str, Enum):
     CLOSED = "closed"
 
     @classmethod
-    def valid_transitions(cls) -> Dict[str, List[str]]:
+    def valid_transitions(cls) -> dict[str, list[str]]:
         """Define valid state transitions."""
         return {
             cls.OPEN: [cls.IN_PROGRESS, cls.WAITING, cls.BLOCKED, cls.CLOSED],
@@ -54,6 +58,7 @@ class TicketState(str, Enum):
 
 class BaseTicket(BaseModel):
     """Base model for all ticket types."""
+
     model_config = ConfigDict(use_enum_values=True)
 
     id: Optional[str] = Field(None, description="Unique identifier")
@@ -61,30 +66,32 @@ class BaseTicket(BaseModel):
     description: Optional[str] = Field(None, description="Detailed description")
     state: TicketState = Field(TicketState.OPEN, description="Current state")
     priority: Priority = Field(Priority.MEDIUM, description="Priority level")
-    tags: List[str] = Field(default_factory=list, description="Tags/labels")
+    tags: list[str] = Field(default_factory=list, description="Tags/labels")
     created_at: Optional[datetime] = Field(None, description="Creation timestamp")
     updated_at: Optional[datetime] = Field(None, description="Last update timestamp")
 
     # Metadata for field mapping to different systems
-    metadata: Dict[str, Any] = Field(
-        default_factory=dict,
-        description="System-specific metadata and field mappings"
+    metadata: dict[str, Any] = Field(
+        default_factory=dict, description="System-specific metadata and field mappings"
     )
 
 
 class Epic(BaseTicket):
     """Epic - highest level container for work (Projects in Linear, Milestones in GitHub)."""
-    ticket_type: TicketType = Field(default=TicketType.EPIC, frozen=True, description="Always EPIC type")
-    child_issues: List[str] = Field(
-        default_factory=list,
-        description="IDs of child issues"
+
+    ticket_type: TicketType = Field(
+        default=TicketType.EPIC, frozen=True, description="Always EPIC type"
+    )
+    child_issues: list[str] = Field(
+        default_factory=list, description="IDs of child issues"
     )
 
-    def validate_hierarchy(self) -> List[str]:
+    def validate_hierarchy(self) -> list[str]:
         """Validate epic hierarchy rules.
 
         Returns:
             List of validation errors (empty if valid)
+
         """
         # Epics don't have parents in our hierarchy
         return []
@@ -92,11 +99,14 @@ class Epic(BaseTicket):
 
 class Task(BaseTicket):
     """Task - individual work item (can be ISSUE or TASK type)."""
-    ticket_type: TicketType = Field(default=TicketType.ISSUE, description="Ticket type in hierarchy")
+
+    ticket_type: TicketType = Field(
+        default=TicketType.ISSUE, description="Ticket type in hierarchy"
+    )
     parent_issue: Optional[str] = Field(None, description="Parent issue ID (for tasks)")
     parent_epic: Optional[str] = Field(None, description="Parent epic ID (for issues)")
     assignee: Optional[str] = Field(None, description="Assigned user")
-    children: List[str] = Field(default_factory=list, description="Child task IDs")
+    children: list[str] = Field(default_factory=list, description="Child task IDs")
 
     # Additional fields common across systems
     estimated_hours: Optional[float] = Field(None, description="Time estimate")
@@ -114,11 +124,12 @@ class Task(BaseTicket):
         """Check if this is a sub-task."""
         return self.ticket_type in (TicketType.TASK, TicketType.SUBTASK)
 
-    def validate_hierarchy(self) -> List[str]:
+    def validate_hierarchy(self) -> list[str]:
         """Validate ticket hierarchy rules.
 
         Returns:
             List of validation errors (empty if valid)
+
         """
         errors = []
 
@@ -132,13 +143,16 @@ class Task(BaseTicket):
 
         # Tasks should not have both parent_issue and parent_epic
         if self.is_task() and self.parent_epic:
-            errors.append("Tasks should only have parent_issue, not parent_epic (epic comes from parent issue)")
+            errors.append(
+                "Tasks should only have parent_issue, not parent_epic (epic comes from parent issue)"
+            )
 
         return errors
 
 
 class Comment(BaseModel):
     """Comment on a ticket."""
+
     model_config = ConfigDict(use_enum_values=True)
 
     id: Optional[str] = Field(None, description="Comment ID")
@@ -146,18 +160,18 @@ class Comment(BaseModel):
     author: Optional[str] = Field(None, description="Comment author")
     content: str = Field(..., min_length=1, description="Comment text")
     created_at: Optional[datetime] = Field(None, description="Creation timestamp")
-    metadata: Dict[str, Any] = Field(
-        default_factory=dict,
-        description="System-specific metadata"
+    metadata: dict[str, Any] = Field(
+        default_factory=dict, description="System-specific metadata"
     )
 
 
 class SearchQuery(BaseModel):
     """Search query parameters."""
+
     query: Optional[str] = Field(None, description="Text search query")
     state: Optional[TicketState] = Field(None, description="Filter by state")
     priority: Optional[Priority] = Field(None, description="Filter by priority")
-    tags: Optional[List[str]] = Field(None, description="Filter by tags")
+    tags: Optional[list[str]] = Field(None, description="Filter by tags")
     assignee: Optional[str] = Field(None, description="Filter by assignee")
     limit: int = Field(10, gt=0, le=100, description="Maximum results")
-    offset: int = Field(0, ge=0, description="Result offset for pagination")
\ No newline at end of file
+    offset: int = Field(0, ge=0, description="Result offset for pagination")
