@@ -1,19 +1,22 @@
 """Background worker for processing queued ticket operations."""
 
 import asyncio
-import json
 import logging
 import signal
-import sys
-import time
-from datetime import datetime, timedelta
-from pathlib import Path
-from typing import Optional, Dict, Any, List
 import threading
+import time
+from datetime import datetime
+from pathlib import Path
+from typing import Any, Optional
+
 from dotenv import load_dotenv
 
-from .queue import Queue, QueueItem, QueueStatus
 from ..core import AdapterRegistry, Task
+from .queue import Queue, QueueItem, QueueStatus
+from .ticket_registry import TicketRegistry
+
+# Import adapters module to trigger registration
+import mcp_ticketer.adapters  # noqa: F401
 
 # Load environment variables from .env.local
 env_path = Path.cwd() / ".env.local"
@@ -28,11 +31,8 @@ LOG_FILE = LOG_DIR / "worker.log"
 
 logging.basicConfig(
     level=logging.INFO,
-    format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-    handlers=[
-        logging.FileHandler(LOG_FILE),
-        logging.StreamHandler()
-    ]
+    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
+    handlers=[logging.FileHandler(LOG_FILE), logging.StreamHandler()],
 )
 logger = logging.getLogger(__name__)
 
@@ -45,7 +45,7 @@ class Worker:
         "linear": 60,
         "jira": 30,
         "github": 60,
-        "aitrackdown": 1000  # Local, no rate limit
+        "aitrackdown": 1000,  # Local, no rate limit
     }
 
     # Retry configuration
@@ -60,7 +60,7 @@ class Worker:
         self,
         queue: Optional[Queue] = None,
         batch_size: int = DEFAULT_BATCH_SIZE,
-        max_concurrent: int = DEFAULT_MAX_CONCURRENT
+        max_concurrent: int = DEFAULT_MAX_CONCURRENT,
     ):
         """Initialize worker.
 
@@ -68,16 +68,18 @@ class Worker:
             queue: Queue instance (creates default if not provided)
             batch_size: Number of items to process in a batch
             max_concurrent: Maximum concurrent operations per adapter
+
         """
         self.queue = queue or Queue()
+        self.ticket_registry = TicketRegistry()
         self.running = False
         self.stop_event = threading.Event()
         self.batch_size = batch_size
         self.max_concurrent = max_concurrent
 
         # Track rate limits per adapter
-        self.last_request_times: Dict[str, datetime] = {}
-        self.adapter_semaphores: Dict[str, asyncio.Semaphore] = {}
+        self.last_request_times: dict[str, datetime] = {}
+        self.adapter_semaphores: dict[str, asyncio.Semaphore] = {}
 
         # Statistics
         self.stats = {
@@ -91,7 +93,9 @@ class Worker:
         signal.signal(signal.SIGTERM, self._signal_handler)
         signal.signal(signal.SIGINT, self._signal_handler)
 
-        logger.info(f"Worker initialized with batch_size={batch_size}, max_concurrent={max_concurrent}")
+        logger.info(
+            f"Worker initialized with batch_size={batch_size}, max_concurrent={max_concurrent}"
+        )
 
     def _signal_handler(self, signum, frame):
         """Handle shutdown signals."""
@@ -103,6 +107,7 @@ class Worker:
 
         Args:
             daemon: Run as daemon process
+
         """
         if self.running:
             logger.warning("Worker already running")
@@ -153,11 +158,12 @@ class Worker:
 
         logger.info("Worker loop stopped")
 
-    def _get_batch(self) -> List[QueueItem]:
+    def _get_batch(self) -> list[QueueItem]:
         """Get a batch of pending items from the queue.
 
         Returns:
             List of queue items to process
+
         """
         batch = []
         for _ in range(self.batch_size):
@@ -168,11 +174,12 @@ class Worker:
                 break
         return batch
 
-    async def _process_batch(self, batch: List[QueueItem]):
+    async def _process_batch(self, batch: list[QueueItem]):
         """Process a batch of queue items with concurrency control.
 
         Args:
             batch: List of queue items to process
+
         """
         logger.info(f"Processing batch of {len(batch)} items")
 
@@ -192,12 +199,13 @@ class Worker:
         # Wait for all adapter groups to complete
         await asyncio.gather(*tasks, return_exceptions=True)
 
-    async def _process_adapter_group(self, adapter: str, items: List[QueueItem]):
+    async def _process_adapter_group(self, adapter: str, items: list[QueueItem]):
         """Process items for a specific adapter with concurrency control.
 
         Args:
             adapter: Adapter name
             items: List of items for this adapter
+
         """
         logger.debug(f"Processing {len(items)} items for adapter {adapter}")
 
@@ -223,8 +231,18 @@ class Worker:
 
         Args:
             item: Queue item to process
+
         """
-        logger.info(f"Processing queue item {item.id}: {item.operation} on {item.adapter}")
+        logger.info(
+            f"Processing queue item {item.id}: {item.operation} on {item.adapter}"
+        )
+
+        # Register operation start in ticket registry
+        title = item.ticket_data.get("title", "Unknown")
+        self.ticket_registry.register_ticket_operation(
+            item.id, item.adapter, item.operation, title, item.ticket_data
+        )
+        self.ticket_registry.update_ticket_status(item.id, "processing")
 
         try:
             # Check rate limit
@@ -238,36 +256,67 @@ class Worker:
             # Process operation
             result = await self._execute_operation(adapter, item)
 
-            # Mark as completed
-            self.queue.update_status(
-                item.id,
-                QueueStatus.COMPLETED,
-                result=result
+            # Extract ticket ID from result if available
+            ticket_id = None
+            if isinstance(result, dict):
+                ticket_id = result.get("id")
+
+            # Mark as completed in both queue and registry (atomic)
+            success = self.queue.update_status(
+                item.id, QueueStatus.COMPLETED, result=result,
+                expected_status=QueueStatus.PROCESSING
             )
+            if success:
+                self.ticket_registry.update_ticket_status(
+                    item.id, "completed", ticket_id=ticket_id, result_data=result
+                )
+            else:
+                logger.warning(f"Failed to update status for {item.id} - item may have been processed by another worker")
+
             self.stats["items_processed"] += 1
-            logger.info(f"Successfully processed {item.id}")
+            logger.info(f"Successfully processed {item.id}, ticket ID: {ticket_id}")
 
         except Exception as e:
             logger.error(f"Error processing {item.id}: {e}")
 
+            # Update registry with error
+            self.ticket_registry.update_ticket_status(
+                item.id, "failed", error_message=str(e), retry_count=item.retry_count
+            )
+
             # Check retry count
             if item.retry_count < self.MAX_RETRIES:
                 # Retry with exponential backoff
-                retry_delay = self.BASE_RETRY_DELAY * (2 ** item.retry_count)
-                logger.info(f"Retrying {item.id} after {retry_delay}s (attempt {item.retry_count + 1}/{self.MAX_RETRIES})")
+                retry_delay = self.BASE_RETRY_DELAY * (2**item.retry_count)
+                logger.info(
+                    f"Retrying {item.id} after {retry_delay}s (attempt {item.retry_count + 1}/{self.MAX_RETRIES})"
+                )
 
-                # Increment retry count and reset to pending
-                self.queue.increment_retry(item.id)
+                # Increment retry count and reset to pending (atomic)
+                new_retry_count = self.queue.increment_retry(
+                    item.id, expected_status=QueueStatus.PROCESSING
+                )
+                if new_retry_count >= 0:
+                    self.ticket_registry.update_ticket_status(
+                        item.id, "queued", retry_count=new_retry_count
+                    )
+                else:
+                    logger.warning(f"Failed to increment retry for {item.id} - item may have been processed by another worker")
 
                 # Wait before retry
                 await asyncio.sleep(retry_delay)
             else:
-                # Max retries exceeded, mark as failed
-                self.queue.update_status(
-                    item.id,
-                    QueueStatus.FAILED,
-                    error_message=str(e)
+                # Max retries exceeded, mark as failed (atomic)
+                success = self.queue.update_status(
+                    item.id, QueueStatus.FAILED, error_message=str(e),
+                    expected_status=QueueStatus.PROCESSING
                 )
+                if success:
+                    self.ticket_registry.update_ticket_status(
+                        item.id, "failed", error_message=str(e), retry_count=item.retry_count
+                    )
+                else:
+                    logger.warning(f"Failed to mark {item.id} as failed - item may have been processed by another worker")
                 self.stats["items_failed"] += 1
                 logger.error(f"Max retries exceeded for {item.id}, marking as failed")
 
@@ -276,6 +325,7 @@ class Worker:
 
         Args:
             adapter: Adapter name
+
         """
         if adapter not in self.RATE_LIMITS:
             return
@@ -302,11 +352,13 @@ class Worker:
 
         Returns:
             Adapter instance
+
         """
         # Load configuration from the project directory where the item was created
-        from ..cli.main import load_config
-        from pathlib import Path
         import os
+        from pathlib import Path
+
+        from ..cli.main import load_config
 
         # Use item's project_dir if available, otherwise use current directory
         project_path = Path(item.project_dir) if item.project_dir else None
@@ -337,7 +389,7 @@ class Worker:
 
         return AdapterRegistry.get_adapter(item.adapter, adapter_config)
 
-    async def _execute_operation(self, adapter, item: QueueItem) -> Dict[str, Any]:
+    async def _execute_operation(self, adapter, item: QueueItem) -> dict[str, Any]:
         """Execute the queued operation.
 
         Args:
@@ -346,6 +398,7 @@ class Worker:
 
         Returns:
             Operation result
+
         """
         operation = item.operation
         data = item.ticket_data
@@ -369,7 +422,11 @@ class Worker:
             ticket_id = data.get("ticket_id")
             state = data.get("state")
             result = await adapter.transition_state(ticket_id, state)
-            return {"id": result.id if result else None, "state": state, "success": bool(result)}
+            return {
+                "id": result.id if result else None,
+                "state": state,
+                "success": bool(result),
+            }
 
         elif operation == "comment":
             ticket_id = data.get("ticket_id")
@@ -377,14 +434,62 @@ class Worker:
             await adapter.add_comment(ticket_id, content)
             return {"success": True}
 
+        # Hierarchy operations
+        elif operation == "create_epic":
+            result = await adapter.create_epic(
+                title=data["title"],
+                description=data.get("description"),
+                **{k: v for k, v in data.items()
+                   if k not in ["title", "description"]}
+            )
+            return {
+                "id": result.id if result else None,
+                "title": result.title if result else None,
+                "type": "epic",
+                "success": bool(result)
+            }
+
+        elif operation == "create_issue":
+            result = await adapter.create_issue(
+                title=data["title"],
+                description=data.get("description"),
+                epic_id=data.get("epic_id"),
+                **{k: v for k, v in data.items()
+                   if k not in ["title", "description", "epic_id"]}
+            )
+            return {
+                "id": result.id if result else None,
+                "title": result.title if result else None,
+                "type": "issue",
+                "epic_id": data.get("epic_id"),
+                "success": bool(result)
+            }
+
+        elif operation == "create_task":
+            result = await adapter.create_task(
+                title=data["title"],
+                parent_id=data["parent_id"],
+                description=data.get("description"),
+                **{k: v for k, v in data.items()
+                   if k not in ["title", "parent_id", "description"]}
+            )
+            return {
+                "id": result.id if result else None,
+                "title": result.title if result else None,
+                "type": "task",
+                "parent_id": data["parent_id"],
+                "success": bool(result)
+            }
+
         else:
             raise ValueError(f"Unknown operation: {operation}")
 
-    def get_status(self) -> Dict[str, Any]:
+    def get_status(self) -> dict[str, Any]:
         """Get worker status.
 
         Returns:
             Status information
+
         """
         queue_stats = self.queue.get_stats()
 
@@ -393,7 +498,9 @@ class Worker:
         if self.stats["start_time"]:
             elapsed = (datetime.now() - self.stats["start_time"]).total_seconds()
             if elapsed > 0:
-                throughput = self.stats["items_processed"] / elapsed * 60  # items per minute
+                throughput = (
+                    self.stats["items_processed"] / elapsed * 60
+                )  # items per minute
 
         return {
             "running": self.running,
@@ -408,14 +515,15 @@ class Worker:
                 "throughput_per_minute": throughput,
                 "uptime_seconds": (
                     (datetime.now() - self.stats["start_time"]).total_seconds()
-                    if self.stats["start_time"] else 0
+                    if self.stats["start_time"]
+                    else 0
                 ),
             },
             "queue_stats": queue_stats,
             "total_pending": queue_stats.get(QueueStatus.PENDING.value, 0),
             "total_processing": queue_stats.get(QueueStatus.PROCESSING.value, 0),
             "total_completed": queue_stats.get(QueueStatus.COMPLETED.value, 0),
-            "total_failed": queue_stats.get(QueueStatus.FAILED.value, 0)
+            "total_failed": queue_stats.get(QueueStatus.FAILED.value, 0),
         }
 
     @classmethod
@@ -427,10 +535,11 @@ class Worker:
 
         Returns:
             Log content
+
         """
         if not LOG_FILE.exists():
             return "No logs available"
 
-        with open(LOG_FILE, "r") as f:
+        with open(LOG_FILE) as f:
             all_lines = f.readlines()
-            return "".join(all_lines[-lines:])
\ No newline at end of file
+            return "".join(all_lines[-lines:])
